@@ -1,16 +1,26 @@
 package Algorithm::Dependency::Ordered;
 
-# This package implements a version of Algorithm::Dependency where the order
-# of the schedule is important.
-#
-# For example, when installing software packages, often their dependencies
-# not only need to be installed, but be installed in the correct order.
-#
-# The much more complex ->schedule method of this class takes these factors
-# into account. Please note that while circular dependencies are possible
-# and legal in unordered dependencies, they are a fatal error in ordered
-# dependencies. For that reason, the schedule method will return an error
-# if a circular dependency is found.
+=pod
+
+=head1 NAME
+
+Algorithm::Dependency::Ordered - Implements an ordered dependency heirachy
+
+=head1 DESCRIPTION
+
+Algorithm::Dependency::Ordered implements the most common variety of
+L<Algorithm::Dependency>, the one in which the dependencies of an item must
+be acted upon before the item itself can be acted upon.
+
+In use and semantics, this should be used in exactly the same way as for the
+main parent class. Please note that the output of the C<depends> method is
+NOT changed, as the order of the depends is not assumed to be important.
+Only the output of the C<schedule> method is modified to ensure the correct
+order.
+
+For API details, see L<Algorithm::Dependency>.
+
+=cut
 
 use 5.005;
 use strict;
@@ -18,7 +28,7 @@ use base 'Algorithm::Dependency';
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.03';
+	$VERSION = '1.04';
 }
 
 
@@ -26,15 +36,15 @@ BEGIN {
 
 
 sub schedule {
-	my $self = shift;
+	my $self   = shift;
 	my $source = $self->{source};
-	my @items = @_ or return undef;
+	my @items  = @_ or return undef;
 	return undef if grep { ! $source->item($_) } @items;
 
 	# The actual items to select will be the same as for the unordered
 	# version, so we can simplify the algorithm greatly by using the
 	# normal unordered ->schedule method to get the starting list.
-	my $rv = $self->SUPER::schedule( @items );
+	my $rv    = $self->SUPER::schedule( @items );
 	my @queue = $rv ? @$rv : return undef;
 
 	# Get a working copy of the selected index
@@ -75,7 +85,7 @@ sub schedule {
 		# to the selected index, and clear the error marker.
 		push @schedule, $id;
 		$selected{$id} = 1;
-		$error_marker = '';
+		$error_marker  = '';
 	}
 
 	# All items have been added
@@ -84,39 +94,19 @@ sub schedule {
 
 1;
 
-__END__
-
 =pod
 
-=head1 NAME
-
-Algorithm::Dependency::Ordered - Implements an ordered dependency heirachy
-
-=head1 DESCRIPTION
-
-Algorithm::Dependency::Ordered implements the most common variety of
-L<Algorithm::Dependency>, the one in which the dependencies of an item must
-be acted upon before the item itself can be acted upon.
-
-In use and semantics, this should be used in exactly the same way as for the
-main parent class. Please note that the output of the C<depends> method is
-NOT changed, as the order of the depends is not assumed to be important.
-Only the output of the C<schedule> method is modified to ensure the correct
-order.
-
-For API details, see L<Algorithm::Dependency>.
-
 =head1 SUPPORT
 
 Bugs should be submitted via the CPAN bug tracker, located at
 
-http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Algorithm%3A%3ADependency
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Algorithm-Dependency>
 
 For general comments, contact the author.
 
 =head1 AUTHOR
 
-Adam Kennedy (Maintainer), L<http://ali.as/>, cpan@ali.as
+Adam Kennedy E<lt>cpan@ali.asE<gt>, L<http://ali.as/>
 
 =head1 SEE ALSO
 
@@ -124,7 +114,8 @@ L<Algorithm::Dependency>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003 - 2004 Adam Kennedy. All rights reserved.
+Copyright (c) 2003 - 2005 Adam Kennedy. All rights reserved.
+
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
