@@ -1,21 +1,57 @@
 package Algorithm::Dependency::Source;
 
-# Algorithm::Dependency::Source implements a parent class for a source
-# of items.
+=pod
+
+=head1 NAME
+
+Algorithm::Dependency::Source - Implements a source of heirachy items
+
+=head1 DESCRIPTION
+
+The Algorithm::Dependency::Source class provides an abstract parent class for
+implementing sources for the heirachy data the algorithm will use. For an
+example of an implementation of this, see
+L<Algorithm::Dependency::Source::File>, which is bundled with the main
+L<Algorithm::Dependency> package.
+
+=head1 METHODS
+
+=cut
 
 use 5.005;
 use strict;
+use Params::Util '_SET';
 use Algorithm::Dependency;
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.03';
+	$VERSION = '1.04';
 }
 
 
 
 
 
+#####################################################################
+# Constructor
+
+=pod
+
+=head2 new @arguments
+
+Although you cannot directly use the C<new> constructor for
+C<Algorithm::Dependency::Source>, it will work the same in all subclasses.
+
+The constructor takes zero or more subclass specific arguments to define the
+location of the source of the items, and returns a new object. Alrough it
+may check that the arguments you passed are valid, the source will usually
+NOT actually load the items from the source, instead defering the loading
+until you need to use the items.
+
+Returns a new object on success, or C<undef> on error.
+
+=cut
+
 sub new {
 	my $class = shift;
 
@@ -36,29 +72,39 @@ sub new {
 		}, $class;
 }
 
-# Load the source
+=pod
+
+=head2 load
+
+The C<load> method is the public method used to actually load the items from
+their storage location into the the source object. The method will
+automatically called, as needed, in most circumstances. You would generally
+only want to use C<load> manually if you think there may be some uncertainty
+that the source will load correctly, and want to check it will work.
+
+Returns true if the items are loaded successfully, or C<undef> on error.
+
+=cut
+
 sub load {
 	my $self = shift;
-	my $class = ref $self;
 
 	# If this is a reload, clean up in preperation
 	if ( $self->{loaded} ) {
-		$self->{loaded} = 0;
-		$self->{items_hash} = undef;
+		$self->{loaded}      = 0;
+		$self->{items_hash}  = undef;
 		$self->{items_array} = undef;
 	}
 
 	# Pass through to the real loader
 	my $items = $self->_load_item_list;
 	return $items unless $items;
-	return undef unless UNIVERSAL::isa( $items, 'ARRAY' );
+	unless ( _SET($items, 'Algorithm::Dependency::Item') ) {
+		die( ref($self) . "::_load_item_list did not return an Algorithm::Dependency::Item set" );
+	}
 
 	# Add the items
 	foreach my $item ( @$items ) {
-		unless ( UNIVERSAL::isa( $item, 'Algorithm::Dependency::Item' ) ) {
-			die "$class\::_load_item_list returned something that was not an Algorithm::Dependency::Item";
-		}
-
 		# Have we added this one already?
 		my $id = $item->id;
 		if ( $self->{items_hash}->{ $id } ) {
@@ -74,88 +120,8 @@ sub load {
 	$self->{loaded} = 1;
 }
 
-# Get a single item by id
-sub item {
-	my $self = shift;
-	my $id = length $_[0] ? shift : return undef;
-	$self->{loaded} or $self->load or return undef;
-
-	# Return the item ( or undef )
-	$self->{items_hash}->{$id};
-}
-
-# Get a list of the items
-sub items {
-	my $self = shift;
-	$self->{loaded} or $self->load or return undef;
-	@{ $self->{items_array} };
-}
-
-# Check the integrity of the source.
-sub missing_dependencies {
-	my $self = shift;
-	$self->{loaded} or $self->load or return undef;
-	
-	# Merged the depends of all the items, and see if
-	# any are missing.
-	my %missing = map { $_ => 1 }
-		grep { ! $self->item($_) }
-		map { $_->depends } $self->items;
-	%missing ? [ sort keys %missing ] : 0;
-}
-
-
-
-
-
-#####################################################################
-# Catch methods our subclass should define but didn't
-
-sub _load_item_list { die "Class $_[0] failed to define the method _load_item_list" };
-
-1;
-
-__END__
-
 =pod
 
-=head1 NAME
-
-Algorithm::Dependency::Source - Implements a source of heirachy items
-
-=head1 DESCRIPTION
-
-The Algorithm::Dependency::Source class provides an abstract parent class for
-implementing sources for the heirachy data the algorithm will use. For an
-example of an implementation of this, see
-L<Algorithm::Dependency::Source::File>, which is bundled with the main
-L<Algorithm::Dependency> package.
-
-=head1 METHODS
-
-=head2 new @arguments
-
-Although you cannot directly use the C<new> constructor for
-C<Algorithm::Dependency::Source>, it will work the same in all subclasses.
-
-The constructor takes zero or more subclass specific arguments to define the
-location of the source of the items, and returns a new object. Alrough it
-may check that the arguments you passed are valid, the source will usually
-NOT actually load the items from the source, instead defering the loading
-until you need to use the items.
-
-Returns a new object on success, or C<undef> on error.
-
-=head2 load
-
-The C<load> method is the public method used to actually load the items from
-their storage location into the the source object. The method will
-automatically called, as needed, in most circumstances. You would generally
-only want to use C<load> manually if you think there may be some uncertainty
-that the source will load correctly, and want to check it will work.
-
-Returns true if the items are loaded successfully, or C<undef> on error.
-
 =head2 item $name
 
 The C<item> method fetches and returns the item object specified by the
@@ -164,6 +130,19 @@ name argument.
 Returns an L<Algorithm::Dependency::Item> object on success, or C<undef> if
 the named item does not exist in the source.
 
+=cut
+
+sub item {
+	my $self = shift;
+	my $id   = length $_[0] ? shift : return undef;
+	$self->{loaded} or $self->load or return undef;
+
+	# Return the item ( or undef )
+	$self->{items_hash}->{$id};
+}
+
+=pod
+
 =head2 items
 
 The C<items> method returns, as a list of objects, all of the items
@@ -173,6 +152,16 @@ as that in the storage location.
 Returns a list of L<Algorithm::Dependency::Item> objects on success, or
 C<undef> on error.
 
+=cut
+
+sub items {
+	my $self = shift;
+	$self->{loaded} or $self->load or return undef;
+	@{ $self->{items_array} };
+}
+
+=pod
+
 =head2 missing_dependencies
 
 By default, we are leniant with missing dependencies if the item is neved 
@@ -184,11 +173,41 @@ If there are any missing dependencies, returns a reference to an array of
 their ids. If there are no missing dependencies, returns 0. Returns 
 C<undef> on error.
 
+=cut
+
+sub missing_dependencies {
+	my $self = shift;
+	$self->{loaded} or $self->load or return undef;
+	
+	# Merged the depends of all the items, and see if
+	# any are missing.
+	my %missing = map  { $_ => 1           }
+	              grep { ! $self->item($_) }
+	              map  { $_->depends       }
+	              $self->items;
+	%missing ? [ sort keys %missing ] : 0;
+}
+
+
+
+
+
+#####################################################################
+# Catch unimplemented methods in subclasses
+
+sub _load_item_list {
+	die "Class $_[0] failed to define the method _load_item_list";
+}
+
+1;
+
+=pod
+
 =head1 EXTENDING
 
-Algorithm::Dependency::Source itself is a fairly thin module, and it is
-intended that you will probably need to extend it to be able to extract
-item data from whatever location you have stored them.
+C<Algorithm::Dependency::Source> itself is a fairly thin module, and it
+is intended that you will probably need to extend it to be able to
+extract item data from whatever location you have stored them.
 
 This is usually a fairly simple two step process.
 
@@ -220,11 +239,11 @@ For general comments, contact the author.
 To file a bug against this module, in a way you can keep track of, see the
 CPAN bug tracking system.
 
-http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Algorithm%3A%3ADependency
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Algorithm-Dependency>
 
 =head1 AUTHOR
 
-Adam Kennedy (Maintainer), L<http://ali.as/>, cpan@ali.as
+Adam Kennedy E<lt>cpan@ali.asE<gt>, L<http://ali.as/>
 
 =head1 SEE ALSO
 
@@ -232,7 +251,8 @@ L<Algorithm::Dependency>, L<Algorithm::Dependency::Source::File>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003 Adam Kennedy. All rights reserved.
+Copyright (c) 2003 - 2005 Adam Kennedy. All rights reserved.
+
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
