@@ -31,15 +31,13 @@ L<Algorithm::Dependency::Source> methods.
 
 =cut
 
-use 5.005;
 use strict;
-use Algorithm::Dependency::Source ();
 use Params::Util qw{_HASH _ARRAY0};
+use base 'Algorithm::Dependency::Source';
 
-use vars qw{$VERSION @ISA};
+use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.105_01';
-	@ISA     = 'Algorithm::Dependency::Source';
+	$VERSION = '1.04';
 }
 
 
@@ -119,7 +117,7 @@ L<Algorithm::Dependency>, L<Algorithm::Dependency::Source>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003 - 2005 Adam Kennedy.
+Copyright (c) 2003 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
